Fix image queue creation

This commit is contained in:
schroda
2025-11-23 00:10:14 +01:00
parent fe4bfd922e
commit 3dfb80a237
2 changed files with 7 additions and 6 deletions

View File

@@ -12,14 +12,16 @@ import { Sources } from '@/features/source/services/Sources.ts';
export class SourceAwareQueue { export class SourceAwareQueue {
private static readonly DEFAULT_ID = '__global__'; private static readonly DEFAULT_ID = '__global__';
private readonly queueBySource = new Map<string, Queue>([ private readonly queueBySource: Map<string, Queue>;
[SourceAwareQueue.DEFAULT_ID, new Queue(this.concurrencyPerSource)],
]);
constructor( constructor(
private readonly areConnectionsLimited: boolean, private readonly areConnectionsLimited: boolean,
private readonly concurrencyPerSource = 5, private readonly concurrencyPerSource = 5,
) {} ) {
this.queueBySource = new Map<string, Queue>([
[SourceAwareQueue.DEFAULT_ID, new Queue(this.concurrencyPerSource)],
]);
}
private getConcurrencyFor(sourceId: string | null): number { private getConcurrencyFor(sourceId: string | null): number {
const isLocalSource = sourceId === Sources.LOCAL_SOURCE_ID; const isLocalSource = sourceId === Sources.LOCAL_SOURCE_ID;

View File

@@ -467,7 +467,7 @@ export class RequestManager {
const isHttps = typeof window !== 'undefined' && window.location.protocol === 'https:'; const isHttps = typeof window !== 'undefined' && window.location.protocol === 'https:';
const isHttp2 = isHttps && this.detectHttp2(); const isHttp2 = isHttps && this.detectHttp2();
this.imageQueue = new SourceAwareQueue(isHttp2, 5); this.imageQueue = new SourceAwareQueue(!isHttp2, 5);
BaseClient.setTokenRefreshCompleteCallback(() => { BaseClient.setTokenRefreshCompleteCallback(() => {
this.processQueues(); this.processQueues();
@@ -954,7 +954,6 @@ export class RequestManager {
private getSourceIdFromUrl(url: string): string | null { private getSourceIdFromUrl(url: string): string | null {
try { try {
console.log('asdf', new URL(url).searchParams.get('sourceId'));
return new URL(url).searchParams.get('sourceId'); return new URL(url).searchParams.get('sourceId');
} catch { } catch {
return null; return null;